
From: Patrick Boettcher <pb@linuxtv.org>

while investigating the QAM_128-issue with the stv0297-driver for the
Cablestar (which is not the same as the one in dvb-kernel CVS, yet), I fixed
it, not by increasing the timeout, but by disabling the corner-detection for
QAM_128 and higher.

This patch has been tested on dvb-kernel cvs, and has been reported to work by
multiple users.  Some cards still need timeout increase on top of this patch. 
This will be addressed later.

Signed-off-by: Patrick Boettcher <pb@linuxtv.org>
Signed-off-by: Michael Krufky <mkrufky@m1k.net>
Signed-off-by: Johannes Stezenbach <js@linuxtv.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/media/dvb/frontends/stv0297.c |    8 +++++++-
 1 files changed, 7 insertions(+), 1 deletion(-)

diff -puN drivers/media/dvb/frontends/stv0297.c~dvb-frontend-stv0297-qam128-tuning-improvement drivers/media/dvb/frontends/stv0297.c
--- devel/drivers/media/dvb/frontends/stv0297.c~dvb-frontend-stv0297-qam128-tuning-improvement	2005-09-04 16:51:24.000000000 -0700
+++ devel-akpm/drivers/media/dvb/frontends/stv0297.c	2005-09-04 16:51:24.000000000 -0700
@@ -606,7 +606,13 @@ static int stv0297_set_frontend(struct d
 	stv0297_set_inversion(state, inversion);
 
 	/* kick off lock */
-	stv0297_writereg_mask(state, 0x88, 0x08, 0x08);
+	/* Disable corner detection for higher QAMs */
+	if (p->u.qam.modulation == QAM_128 ||
+		p->u.qam.modulation == QAM_256)
+		stv0297_writereg_mask(state, 0x88, 0x08, 0x00);
+	else
+		stv0297_writereg_mask(state, 0x88, 0x08, 0x08);
+
 	stv0297_writereg_mask(state, 0x5a, 0x20, 0x00);
 	stv0297_writereg_mask(state, 0x6a, 0x01, 0x01);
 	stv0297_writereg_mask(state, 0x43, 0x40, 0x40);
_
